Module control_plane

Module control_plane 

Structs

ControlPlane
A control plane that a data flow reports back to. The url is the base address used to build control-plane notification callbacks. Data flows reference a control plane by its id (see DataFlow::control_plane_id).
ControlPlaneBuilder
Use builder syntax to set the inputs and finish with build().