Module data_address
dataplane_
sdk
0.1.1
Module data_
address
Module Items
Structs
In dataplane_
sdk::
core::
model
dataplane_sdk
::
core
::
model
Module
data_
address
Structs

Data
Address
Data
Address
Builder
Use builder syntax to set the inputs and finish with
build()
.
Endpoint
Property
Endpoint
Property
Builder
Use builder syntax to set the inputs and finish with
build()
.