Structs
- Data
Flow Prepare Message - Data
Flow Prepare Message Builder - Use builder syntax to set the inputs and finish with
build(). - Data
Flow Resume Message - Data
Flow Resume Message Builder - Use builder syntax to set the inputs and finish with
build(). - Data
Flow Start Message - Data
Flow Start Message Builder - Use builder syntax to set the inputs and finish with
build(). - Data
Flow Started Notification Message - Data
Flow Started Notification Message Builder - Use builder syntax to set the inputs and finish with
build(). - Data
Flow Status Message - Data
Flow Status Message Builder - Use builder syntax to set the inputs and finish with
build(). - Data
Flow Status Response Message - Data
Flow Status Response Message Builder - Use builder syntax to set the inputs and finish with
build(). - Data
Flow Suspend Message - Data
Flow Terminate Message - Data
Flow Terminate Message Builder - Use builder syntax to set the inputs and finish with
build().