DataPlaneSdk

Struct DataPlaneSdk 

pub struct DataPlaneSdk<C: TransactionalContext>(/* private fields */);

Implementations

Methods from Deref<Target = DataPlaneSdkInternal<C>>

pub async fn start( &self, participant_context_id: &str, control_plane_id: &str, req: DataFlowStartMessage, ) -> SdkResult<DataFlowStatusMessage>

pub async fn prepare( &self, participant_context_id: &str, control_plane_id: &str, req: DataFlowPrepareMessage, ) -> SdkResult<DataFlowStatusMessage>

pub async fn terminate( &self, _ctx: &str, flow_id: &str, reason: Option<String>, ) -> SdkResult<()>

pub async fn started( &self, _ctx: &str, flow_id: &str, msg: DataFlowStartedNotificationMessage, ) -> SdkResult<()>

pub async fn completed(&self, _ctx: &str, flow_id: &str) -> SdkResult<()>

pub async fn suspend( &self, _ctx: &str, flow_id: &str, reason: Option<String>, ) -> SdkResult<()>

pub async fn resume( &self, _ctx: &str, flow_id: &str, msg: DataFlowResumeMessage, ) -> SdkResult<DataFlowStatusMessage>

pub async fn status( &self, _ctx: &str, flow_id: &str, ) -> SdkResult<DataFlowStatusResponseMessage>

pub async fn notify_prepared( &self, ctx: &str, flow_id: &str, data_address: Option<DataAddress>, ) -> SdkResult<()>

Notifies the control plane that the data flow has been prepared, by POSTing to the URL of the flow’s referenced control plane (resolved from control_plane_id). See the Data Plane Signaling “Control Plane Endpoint” section.

pub async fn notify_started( &self, ctx: &str, flow_id: &str, data_address: Option<DataAddress>, ) -> SdkResult<()>

Notifies the control plane that the data flow has started.

pub async fn notify_completed(&self, ctx: &str, flow_id: &str) -> SdkResult<()>

Notifies the control plane that the data flow has completed.

pub async fn notify_errored( &self, ctx: &str, flow_id: &str, error: Option<String>, ) -> SdkResult<()>

Notifies the control plane that the data flow has errored. The optional error is forwarded as the error field of the status message.

pub async fn fetch_by_id( &self, tx: &mut C::Transaction, flow_id: &str, ) -> SdkResult<Option<DataFlow>>

pub fn ctx(&self) -> &C