Structs
- Control
Plane - A control plane that a data flow reports back to. The
urlis the base address used to build control-plane notification callbacks. Data flows reference a control plane by itsid(seeDataFlow::control_plane_id). - Control
Plane Builder - Use builder syntax to set the inputs and finish with
build().